#ifndef ARBITRATOR_H
#define ARBITRATOR_H

#include <QObject>

//The arbitrator knows everyone.
class CellWidget;
class MenuWidget;
class SettingsWidget;
class MenokuWidget;
class MenuData;
class MenokuTray;

//The Arbitrator class manages communication between all the various widgets
//in the program. It's a bit messy, but in being that way it keeps the rest of
//the program cleaner.
class Arbitrator : public QObject {
    Q_OBJECT
    public:
        Arbitrator();
		
		//Various widgets "check in" using these methods. The Arbitrator
		//might read data from them, tweak them, or make connections.
        void supplyCells(CellWidget** cells);
        void supplyMenu(MenuWidget* menu);
        void supplySettings(SettingsWidget* settings);
        void supplyMenoku(MenokuWidget* menoku);
		void supplyTray(MenokuTray* tray);

		//called when the currently loaded menu changes. This is mainly to
		//keep the clipboard in sync with the current menu so that no
		//MenuData object has the wrong parent field.
        void menuChanged();

		//Is the program in edit mode?
        bool edit();
		//The currently loaded menu.
        MenuData* menu();
		//The user has signaled that he wants to activate an item.
        void requestActivation(CellWidget* cell, int index);
		//an as-of-yet unset item has been "activated" by the user
        void emptyActivation(CellWidget* cell, int index);
		//the user has right clicked on a cell, but not on any of its items
        void clickedCell(CellWidget* cell);

		//apply modifications made to an item by the SettingsWidget
        void applyItem();
		//cancel modifying an item with the SettingsWidget
        void cancelItem();
		//delete the item currently being edited in the SettingsWidget
        void deleteItem();
    signals:
		//this is emited when the edit state of the program has changed
		//(ie, when the side panel is hidden or shown)
        void setEdit(bool edit);
		//when this is emited, all cell widgets must redraw themselves. Mainly
		//this happens when icon rendering options change.
        void invalidateCells();
		//this is emited when the hot key setting has been changed
		void updateHotKey(QString newKey);
    public slots:
		//switch between edit mode and non-edit mode
        void toggleEdit();
    protected:
		//forget that anything had been selected
        void clearSelection();
	
		//various widgets
        MenokuWidget* m_menoku;
        SettingsWidget* m_settings;
        MenuWidget* m_menu;
		//the cell that contains the selected item
        CellWidget* m_cell;
		//the index of the selected item
        int m_index;

		//whether or not the app is in edit mode
        bool m_edit;
};

//All classes that need the Arbitrator see and use this one instance.
//declared in main.cpp
extern Arbitrator* boss;

#endif //ARBITRATOR_H

