#ifndef BROWSE_BUTTON_H
#define BROWSE_BUTTON_H

#include <QPushButton>

//A QtDesigner plugin for this class has been made, and is available upon request.

//A simple button that, when clicked, asks the user for a file.
//when the dialog is done, a signal is emited with the result.
class BrowseButton : public QPushButton {
    Q_OBJECT
    Q_PROPERTY(QString caption READ caption WRITE setCaption DESIGNABLE true)
    Q_PROPERTY(QString startingDir READ startingDir WRITE setStartingDir DESIGNABLE true)
    Q_PROPERTY(QString filter READ filter WRITE setFilter DESIGNABLE true)
    Q_PROPERTY(bool getDir READ getDir WRITE setGetDir DESIGNABLE true)
    public:
		//inherited constructors:
        BrowseButton(QWidget* parent = 0);
        BrowseButton(const QString& text, QWidget* parent = 0);
        BrowseButton(const QIcon& icon, const QString& text, QWidget* parent = 0);

		//settings to be passed on to the file dialog:
        const QString caption() { return m_caption; }
        const QString startingDir() { return m_dir; }
        const QString filter() { return m_filter; }
		//true if I should ask the user for a directory, not a file.
        const bool getDir() { return m_get_dir; }
    signals:
		//the user chose a file in the dialog.
        void chose(QString file);
		//the user canceled the dialog.
        void canceled();
	public slots:
		//set the various details of the file dialog.
        void setCaption(QString caption) { m_caption = caption; }
        void setFilter(QString filter) { m_filter = filter; }
        void setStartingDir(QString dir) { m_dir = dir; }
        void setGetDir(bool getDir) { m_get_dir = getDir; }
    protected:
		//this is where the file dialog is shown
        void mouseReleaseEvent(QMouseEvent* e);
		
		//state variables:
        QString m_caption;
        QString m_dir;
        QString m_filter;
        bool m_get_dir;
};

#endif //BROWSE_BUTTON_H
