#ifndef CELLDATA_H_
#define CELLDATA_H_

#include <QString>

class ItemData;

//The CellData class represents a "cell", a group of nine icons.
//This information is rendered in the CellWidget class.
class CellData
{
public:
	//default constructor
	CellData(const QString &name = "Unnamed");
	//copy constructor (deep copy)
	CellData(CellData* cell);
	//set the value of this cell data to the data in another cell (deep copy)
	void copy(CellData* cell);
	//recursively delete all the items in this cell
	~CellData();

	//the title for this cell
	QString const name();
	void setName(const QString &name);
	//the number of items in this cell
	int const count();

	//access the indexth item
	ItemData* item(int index);
	//access some item in this cell (useful if there is only one item)
	ItemData* item();
	//the index of the item returned by the above procedure
	int itemIndex();
	//set the indexth item. (will delete any item already in that position)
	void setItem(int index, ItemData* item);
	//remove the indexth item and delete it.
	void clearItem(int index);
	//remove and delete all items in this cell
	void clear();
	
	//create a printed representation, in XML, to save in a file.
	QString toString(int pos, const QString &indent = "");

protected:
	//state variables
	QString m_name;
	int m_count;
	ItemData* m_items[9];
	ItemData* m_item;
	int m_item_index;
};

#endif /*CELLDATA_H_*/
