#ifndef FILE_PARSER_H
#define FILE_PARSER_H

#include <QXmlDefaultHandler>
#include <QString>

class ItemData;
class CellData;
class MenuData;

//A simple XML parser for reading in menu files and constructing trees of
//MenuData, CellData, and ItemData objects.
class FileParser : private QXmlDefaultHandler {
public:
	//parse an XML menu! Returns apointer to the root MenuData object or NULL
	//if the parse failed.
	MenuData* parse(const QString &filename);
	//returns a string explaining why the last call to parse failed.
	QString errorString() { return m_error; }
	
protected:

	//This is an event driven parser, so it has to know what state it's in.
	//Certain tags are only valid in certain states.
	enum State {
		StateNone,
		StateDone,
		StateMenu,
		StateCell,
		StateExec
	};

	//an openning tag was found while reading the file
	bool startElement(const QString &namespaceURI, const QString &localName,
                      const QString &qName, const QXmlAttributes &attributes);
	//a closing tag was found.
	bool endElement(const QString &namespaceURI, const QString &localName,
					const QString &qName);
	//some text between tags was found
	bool characters(const QString &str);
	
	//the document locator is set through this function. This lets me know
	//which line an error occured on.
	void setDocumentLocator(QXmlLocator *locator);
	//records an error message
	void setError(QString error);
	//handlers for errors raised by QXmlDefaultHandler.
	//Note I don't care about warnings, so that handler isn't implemented.
	bool error(const QXmlParseException &exception);
	bool fatalError(const QXmlParseException &exception);

	//the error message
	QString m_error;
	//the state the parser is in
	State m_state;
	//the root menu file
	MenuData* m_root;
	//the menu currently being parsed
	MenuData* m_menu;
	//the cell currently being parsed
	CellData* m_cell;
	//the item currently being parsed
	ItemData* m_item;
	
	//the document locator for the XML file being parsed.
	QXmlLocator* m_locator;
};

#endif //FILE_PARSER_H
