#ifndef ICON_FACTORY_H
#define ICON_FACTORY_H

#include <QPixmap>
#include <QHash>
#include <QString>

class ItemData;
class MenuData;

//a class for loading and, optionally, caching/resizing icon pixmaps.
class IconFactory {
    public:
        IconFactory();

		//look up an icon.
        QPixmap iconFor(ItemData* item);
		//update settings from QSettings
        bool updateSettings();
		//rebuild the entire cache from scratch
        void rebuildCache();
		//empty out the cache.
        void clearCache();

    protected:
		//add one icon to the cache
        void cacheIcon(ItemData* item);
		//recursive procedure to rebuild one menu and its children
        void rebuildMenu(MenuData* menu);

		//a hashtable to serve as my cache.
        QHash<QString, QPixmap> m_icon_cache;
		//the default pixmaps to use when I can't find a better one.
        QPixmap m_generic_exec;
        QPixmap m_generic_menu;

		//options from QSettings
        bool m_cache_all_icons;
        bool m_resize_all_icons;
        int m_resize_width;
        int m_resize_height;
        QString m_generic_exec_icon;
        QString m_generic_menu_icon;
};

//declared in main.cpp
extern IconFactory* iconFactory;

#endif //ICON_FACTORY_H
