#include "ItemData.h"
#include "MenuData.h"

ItemData::ItemData(const QString &name, const QString &icon) {
	m_name = name;
	m_icon = icon;
	
	m_type = ItemExec;
	m_menu = NULL;
}

ItemData::ItemData(ItemData* item) {
    m_name = item->m_name;
    m_icon = item->m_icon;
    m_type = item->m_type;
    if (m_type == ItemExec) {
        m_exec = item->m_exec;
        m_menu = NULL;
    }
    else {
        m_menu = new MenuData(item->m_menu);
    }
}

ItemData::~ItemData() {
    if (m_type == ItemMenu) {
        delete m_menu;
    }
}

QString const ItemData::name() {
	return m_name;
}

void ItemData::setName(const QString &name) {
    m_name = name;
}

QString const ItemData::icon() {
	return m_icon;
}

void ItemData::setIcon(const QString &icon) {
    m_icon = icon;
}

ItemData::ItemType const ItemData::type() {
	return m_type;
}

QString const ItemData::exec() {
	return m_exec;
}

void ItemData::setExec(const QString &exec) {
    m_type = ItemExec;
	m_exec = exec;
	//make sure we don't have any useless data lying around...
	if (m_menu) {
        delete m_menu;
	}
}

MenuData* ItemData::menu() {
	return m_menu;
}

void ItemData::setMenu(MenuData* menu) {
    m_type = ItemMenu;
    m_menu = menu;
    m_exec = "";
}

QString ItemData::toString(int pos, const QString &indent) {
	QString result;
	//the name and icon appear in double quotes, so, make sure no double quote
	//characters occur within them.
    QString e_name = m_name;
    e_name.replace(QChar('"'),"&quot;");
    QString e_icon = m_icon;
    e_icon.replace(QChar('"'),"&quot;");
	if (m_type == ItemExec) {
		result = indent + "<exec pos=\"" + QString::number(pos) + "\"";
		if (!e_icon.isEmpty())
			result += " icon=\"" + e_icon + "\"";
        QString e_exec = m_exec;
		//the command to execute appears outside of quotes, so there are more
		//characters to worry about. These will automatically be converted back
		//when parsed by the Qt XML reader.
 		e_exec.replace(QChar('&'),"&amp;");
		e_exec.replace(QChar('<'),"&lt;");
		e_exec.replace(QChar('>'),"&gt;");
		result += " name=\"" + e_name + "\">" + e_exec + "</exec>\n";
	}
	else {
		//we print the menu tag here because it is actually an item and must
		//take its name from this object. The MenuData class will handle printing
		//everything that goes between menu tags.
		result = indent + "<menu pos=\"" + QString::number(pos) + "\"";
		if (!e_icon.isEmpty())
			result += " icon=\"" + e_icon + "\"";
		result += " name=\"" + e_name + "\">\n";
		result += m_menu->toString(indent + "\t");
		result += indent + "</menu>\n";
	}
	return result;
}
