#include "MenokuTray.h"

#include <QMenu>
#include <QApplication>
#include <QKeySequence>
#include <QSettings>
#include <QtDebug>
#include "DefaultSettings.h"

MenokuTray::MenokuTray()
	: TrayIcon(QPixmap(":trayicon.png"),"Menoku") {
	
	//construct the popup menu
    m_menu = new QMenu();
    m_menu->addAction("Show/Hide Menoku",this,SIGNAL(toggleVisible()));
    m_menu->addAction("Quit",qApp,SLOT(quit()));
    setPopup(m_menu);
	
    connect(this,SIGNAL(clicked(const QPoint&,int)),this,SIGNAL(toggleVisible()));
    connect(this,SIGNAL(closed()),qApp,SLOT(quit()));

	//read the hotkey from QSettings
    QSettings settings;
    settings.beginGroup(WINDOW_OPTIONS);
    QKeySequence hotkey(settings.value(HOT_KEY,HOT_KEY_DEFAULT).toString());
	//if it is valid, use it.
    if (!hotkey.isEmpty()) {
		//note that I have modified the Psi AccelManager to have a simpler interface
        m_accel.setAccel(hotkey);
    }
    connect(&m_accel,SIGNAL(activated(int)),this,SIGNAL(toggleVisible()));
}

MenokuTray::~MenokuTray() {
	delete m_menu;
}

void MenokuTray::updateHotKey(QString newKey) {
	//remove the old hotkey
    m_accel.removeAccel();
    
	//and set up the new one, if it's valid.
    QKeySequence hotkey(newKey);
    if (!hotkey.isEmpty()) {
        m_accel.setAccel(hotkey);
    }
}
