#include "MenokuWidget.h"

#include "MenuWidget.h"
#include "CellWidget.h"
#include "SettingsWidget.h"
#include "Arbitrator.h"
#include <QPushButton>
#include <QLayout>
#include <QApplication>
#include <QMessageBox>
#include <QSettings>
#include <QCloseEvent>
#include "DefaultSettings.h"

using namespace Qt;

MenokuWidget::MenokuWidget(MenuData* menu, QWidget* parent)
    : QWidget(parent){
	
	setWindowTitle("Menoku ("APP_VERSION")");
	
    QHBoxLayout *layout = new QHBoxLayout(this);

	//This has to be called BEFORE the other supply methods in this constructor
	//I would have put this line in main.cpp otherwise.
    boss->supplyMenoku(this);
    
	//The menu containing nine CellWidgets
    m_menu = new MenuWidget();
    layout->addWidget(m_menu);
    boss->supplyMenu(m_menu);
    m_menu->setFocus();

	//the button to toggle in and out of edit mode (show/hide the side panel)
    m_revealer = new QPushButton(">");
    m_revealer->setMaximumWidth(20);
    m_revealer->setFocusPolicy(NoFocus);
    m_revealer->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Minimum);
    layout->addWidget(m_revealer);

	//The widget that lets the user configure settings
    m_settings = new SettingsWidget();
    layout->addWidget(m_settings);
    m_settings->hide();
    boss->supplySettings(m_settings);

    connect(m_revealer,SIGNAL(clicked()),
            boss,      SLOT(toggleEdit()));

	//load the menu to use!
    m_menu->loadMenu(menu);
}

void MenokuWidget::setEdit(bool edit) {
    //turn off the layout to keep it from being clever and resizing the menu
	//(resizing the menu is a heavy computation)
    layout()->setEnabled(false);

    //offset is the size difference between this widget with and without
	//the sidebar for settings.

	//if we're in edit mode, SHOW The sidebar.
    if (edit) {
		//work out the geometry and resize the window.
        m_settings->setFixedWidth(m_menu->width() / 3);
        int offset = m_settings->width() + layout()->spacing();
        m_revealer->setText("<");
        resize(width()+offset,height());
        m_settings->show();
    }
    else {
        int offset = m_settings->width() + layout()->spacing();
        m_revealer->setText(">");
        resize(width()-offset,height());
        m_settings->hide();
    }
	//turn the layout back on now that everything's in place.
    layout()->setEnabled(true);
}

void MenokuWidget::toggleVisible() {
    if (isVisible()) {
        hide();
    }
    else {
        show();
    }
}

void MenokuWidget::closeEvent(QCloseEvent* e) {
	//I want to warn the user, let him know that he's not ACTUALLY closing the
	//program (I hate it when programs don't do this) However, I use QSettings
	//to let him hide this warning forever if he wants.
    QSettings settings;
    settings.beginGroup(WINDOW_OPTIONS);
    if (!settings.value(WARN_ON_CLOSE,WARN_ON_CLOSE_DEFAULT).toBool()) {
        hide();
        e->ignore();
        return;
    }

	//This dialog has the option to quit anyway! A nice thing to have. I might
	//make this behavior configurable... allow to hide with minimize and close
	//with close... who knows.
    int result = QMessageBox::warning(0,
                                      "Hiding window to system tray...",
                                      "Closing the Menoku window doesn't actually stop Menoku from running.\n"
                                      "Instead, the Menoku window is hidden but the Menoku tray icon remains.\n"
                                      "To close Menoku, right click on the Menoku tray icon and select \"Quit\".",
                                      "Don't warn me again",
                                      "Quit anyway",
                                      "Okay",
                                      2,
                                      1);
    switch (result) {
		//close and don't tell me again:
        case 0:
            settings.setValue(WARN_ON_CLOSE,false);
		//just close it:
        case 2:
            hide();
            e->ignore();
            break;
		//no, really, quit Menoku:
        case 1:
            e->accept();
    }
}

