#include "MenuData.h"

#include "CellData.h"

MenuData::MenuData(const QString &name, MenuData* parent)
{
	m_name = name;
	m_parent = parent;
	for (int i = 0; i < 9; i++) {
		m_cells[i] = NULL;
	}
}

MenuData::MenuData(MenuData* menu) {
    m_name = menu->m_name;
    m_parent = menu->m_parent;
    for (int i = 0; i < 9; i++) {
        m_cells[i] = new CellData(menu->m_cells[i]);
    }
}

MenuData::~MenuData()
{
	//recursive delete! All you have to do is delete the root menu and everything
	//else will delete itself. You can also prune branches off of the menu tree
	//by just deleting a single item (which will kill its submenu, if there is
	//one). Never delete a cell, though, outside of this procedure. I want to
	//make sure that a menu always has nine cells.
	for (int i = 0; i < 9; i++) {
       	delete m_cells[i];
	}
}

QString const MenuData::name() {
	return m_name;
}

void MenuData::setName(const QString &name) {
    m_name = name;
}

QString const MenuData::path() {
	//If I have a parent, I'm not the root menu.
	if (m_parent) {
		return m_parent->path() + m_name + "/";
	}
	else {
		//The decoration for the root menu:
		return "/";
	}
}

MenuData* MenuData::parent() {
	return m_parent;
}

void MenuData::setParent(MenuData* parent) {
    m_parent = parent;
}

CellData* MenuData::cell(int index) {
	return m_cells[index];
}

void MenuData::setCell(int index, CellData* cell) {
	//delete the old cell before I overwrite it.
    if (m_cells[index]) {
        delete m_cells[index];
    }
	m_cells[index] = cell;
}

void MenuData::clearCell(int index) {
	//Unlike in cell where clearing an item leaves that spot empty,
	//clearing a cell here just resets it. This is because I want to keep nine
	//cells in every menu  ;)
    m_cells[index]->clear();
}

void MenuData::fill() {
	//fill in any gaps. This is mainly used after a menu has been parsed from
	//a file. I don't require that a menu file has all nine cells for every menu,
	//though any XML file Menoku produces will.
    for (int i = 0; i < 9; i++) {
        if (!m_cells[i]) {
            CellData* cell = new CellData;
            m_cells[i] = cell;
        }
    }
}

QString MenuData::toString(QString indent) {
	QString result;

	//If this is the root menu, some extra decoration is needed.
	if (m_parent == NULL) {
		result = "<!DOCTYPE Menoku-Menu-File >\n\n<rootmenu version=\""APP_VERSION"\">\n";
		indent = "\t";
	}

	//draw all of my cells (in the order they appear on the keypad)	
	for (int start = 6; start >= 0; start -= 3) {
		for (int i = start; i < start+3; i++) {
			if (m_cells[i]) {
				result += m_cells[i]->toString(i+1,indent);
			}
		}
	}
	
	//close the rootmenu tag.
	if (m_parent == NULL) {
		result += "</rootmenu>\n";
	}
	return result;
}
