#ifndef MENUDATA_H_
#define MENUDATA_H_

#include <QString>
class CellData;

//A class to represent an entire menu worth nine cells of nine icons
class MenuData
{
public:
	MenuData(const QString &name, MenuData* parent);
	//a copy constructor (deep)
	MenuData(MenuData* menu);
	~MenuData();

	QString const name();
	void setName(const QString &name);
	//The "path" of a menu is a combination of its name and the names of all
	//of its parent menus. It's like a file path, only with menus  ;)
	QString const path();
 
 	//what menu is the parent of this one. This is used to computer path() and
	//to figure out which menu should be loaded when the user wants to go up
	//a level.
	MenuData* parent();
	void setParent(MenuData* parent);

	//access individual cells. Returns null if there is no cell at the given
	//index. However, in normal execution, this will never happen. The fill()
	//procedure should be called after building a menu, ensuring that it has
	//a cell in every position (even if that cell is empty)
	CellData* cell(int index);
	void setCell(int index, CellData* cell);
	void clearCell(int index);

    //fill MUST be called after a menu is created by the file parser.
    //this ensures that all cells have some data associated with them.
	//(makes drag and drop much simpler)
	void fill();

	//create an XML representation of this menu for output to a file.
	QString toString(QString indent = "");

protected:
	//state variables:
	QString m_name;
	CellData* m_cells[9];
	MenuData* m_parent;
};

#endif /*MENUDATA_H_*/
