#ifndef MENU_WIDGET_H
#define MENU_WIDGET_H

#include <QWidget>

class CellWidget;
class QLabel;
class MenuData;

//A widget to represnet a MenuData object. Mainly, it acts as a container for
//nine CellWidget objects.
class MenuWidget : public QWidget {
	//The arbitrator's allowed to peek, for simplicity's sake.
	friend class Arbitrator;
	Q_OBJECT
	public:
		//the default QWidget constructor
    	MenuWidget(QWidget* parent = 0);

	signals:
		//signal that the user wants to hide the window (pressed escape)
    	void toggleVisible();

	public slots:
		//load a new menu
    	void loadMenu(MenuData* menu);
		//go up to the previous menu
    	void up();
		//highlight one cell and let the user pick an item inside that cell
		//(give that CellWidget keyboard focus)
    	void select(CellWidget* cell);
		//restore all the cells to their normal state and take back keyboard
		//focus so that he can choose a new cell.
    	void deselect();

	protected:
		//the label to display the path of the current menu
    	QLabel* m_path_label;
		//input from the user
    	void keyPressEvent(QKeyEvent *e);
		//nine CellWidgets
    	CellWidget* m_cells[9];

		//whether there is a "selected" cell receiving key presses from the user
    	bool m_selected;
		//the actual menu associated with this.
    	MenuData* m_data;
};

#endif //MENU_WIDGET_H

