#ifndef SETTINGS_WIDGET_H
#define SETTINGS_WIDGET_H

#include <QWidget>
#include "ui_settings.h"

class ItemData;
class CellData;

//A Widget to let the user configure settings for Menoku. This widget was made
//with QtDesigner and is used through the schmancy UI system.
class SettingsWidget : public QWidget, protected Ui::Settings {
	friend class Arbitrator;
	Q_OBJECT
	public:
		//Normal QWidget constructor
    	SettingsWidget(QWidget* parent = 0);
    	~SettingsWidget();
	signals:
		//notify the tray Icon that the hotkey has changed
		void updateHotKey(QString newKey);
	public slots:
		//toggle in and out of edit mode
    	void setEdit(bool edit);
		//set the item that the user wants to edit
    	void setItem(ItemData* item);
		//unset the item to edit
    	void clearItem();
	protected slots:
		//the user clicked one of these three buttons
    	void applyClick();
    	void cancelClick();
    	void deleteClick();
	protected:
 		void resizeEvent(QResizeEvent*);
		//disable editting widgets when nothing is selected
 		void setEditEnabled(bool enabled);
		//the item being edited
    	ItemData* m_item;
		//the CellData representing the clipboard. (NOT the CellWidget)
    	CellData* m_cell;
};

#endif //SETTINGS_WIDGET_H

